@@ -309,6 +309,11 @@ def getMask(iface):
     netmask = socket.ntohl(struct.unpack('16sH2xI8x', res)[2])
     return numMaskToCidr(netmask)
 
+def isWireless(iface):
+    """
+    Является ли данное устройство беспроводным
+    """
+    return device.sysfs.exists(device.sysfs.Path.ClassNet, iface, "wireless")
 
 def getMac(iface):
     """
